<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Elementor_portfolio extends Widget_Base
{
	public function get_name()
	{
		return 'Elementor-portfolio-widget';
	}

	public function get_title()
	{
		return __('Zc >  Portfolio', 'lixer');
	}

	public function get_icon()
	{
		return 'eicon-icon-box';
	}

	protected function _register_controls()
	{
		$traits = new \Lixer_Elementor_Traits($this);
		$this->start_controls_section('section_tab', ['label' => esc_html__('Portfolio', 'lixer'),]);
        $this->add_control(

			'icon_img',

			[

				'label' => esc_html__( 'Icon Image' ,'lixer'),
				'type' => Controls_Manager::MEDIA,
                'condition'      => [
                          'style' =>['style3','style7','style8','style10'],
                        ],
			]

			);
        
        $this->add_control(

			'text_heading',

			[

				'label' => esc_html__( 'Heading' ,'lixer'),
				'type' => Controls_Manager::TEXT,
                'condition'      => [
                        'style' =>['style3','style7','style10','style11','style13'],
                        ],

			]

			);
        $this->add_control(
        'button_text', [
        'label'             =>esc_html__( 'Button Text', 'lixer' ),
        'type'             => Controls_Manager::TEXT,
        'condition'      => [
        'style' =>['style1','style2','style3','style7','style10','style11'],
        ],
        ]
        );
        $this->add_control(
        'button_link', [
        'label'             =>esc_html__( 'Button URL', 'lixer' ),
        'type'             => Controls_Manager::URL,
        'condition'      => [
        'style' => ['style1','style2','style3','style7','style10','style11'],
        ],
        ]
        );
        $this->add_control(

			'text_social',

			[

				'label' => esc_html__( 'Social Icon' ,'lixer'),
				'type' => Controls_Manager::TEXTAREA,
                'condition'      => [
                        'style' =>['style3'],
                        ],

			]

			);
        $this->add_control(

			'back_img',

			[

				'label' => esc_html__( 'Background Image' ,'lixer'),
				'type' => Controls_Manager::MEDIA,
                'condition'      => [
                          'style' =>['style4','style8'],
                        ],
			]

			);
        
        
        
      
        $this->add_control(
			'posts_per_page',
			[
				'label'   => esc_html__( 'Number of items to show', 'lixer' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 7,
			]
		);
        
        $this->add_control(
			'select_categories',
			[
				'label' => esc_html__( 'Filter by Categories', 'lixer' ),
				'type' => Controls_Manager::SELECT2,
				'options' => lixer_el()->get_terms_dropdown_array([
					'taxonomy' => 'category',
					'hide_empty' => false,
					]),
				'multiple' => true,
			]
		);

        
		$this->add_control(
			'style',
			[
				'type' => Controls_Manager::SELECT, 'label' => esc_html__('Choose Style', 'lixer'), 'default' => 'style1',
				'label_block' => true, 'options' => [
					'style1' => esc_html__('Creative Portfolio', 'lixer'), 
                    'style2' => esc_html__('Project gallery', 'lixer'),
                    'style11' => esc_html__('Project gallery Two', 'lixer'),
					'style3' => esc_html__('Project Slider', 'lixer'), 
					'style4' => esc_html__('Vertical Slider', 'lixer'), 
					'style5' => esc_html__('Project Stripes', 'lixer'), 
					'style6' => esc_html__('Project Metro', 'lixer'), 
					'style7' => esc_html__('Project Minimal', 'lixer'), 
					'style8' => esc_html__('Interactive Showcase', 'lixer'), 
					'style9' => esc_html__('Horizontal Project Slider', 'lixer'), 
					'style10' => esc_html__('Designer Portfolio', 'lixer'), 
					'style12' => esc_html__('Portfolio Huge', 'lixer'), 
					'style13' => esc_html__('Portfolio Agency', 'lixer'), 
				],
			]
		);
		$this->end_controls_section();
	}
	protected function render($instance = [])
	{
		$settings = $this->get_settings();
        $back_img = $settings[ 'back_img' ];  
        $icon_img = $settings[ 'icon_img' ];  
        $button_text = $settings[ 'button_text' ];
        $button_link = $settings[ 'button_link' ];
        $text_heading = $settings[ 'text_heading' ];  
        $text_social = $settings[ 'text_social' ];  
        $posts_per_page = $settings['posts_per_page'];
         $category = $settings['select_categories'];
		$style = $settings['style'];
		switch ($style) {
			case 'style1':
				require get_template_directory() . '/inc/sections/portfolio/style1.php';
				break;
                
            case 'style2':
				require get_template_directory() . '/inc/sections/portfolio/style2.php';
				break;              
          

			case 'style3':
				require get_template_directory() . '/inc/sections/portfolio/style3.php';
				break;
                
            case 'style4':
				require get_template_directory() . '/inc/sections/portfolio/style4.php';
				break;
                
            case 'style5':
				require get_template_directory() . '/inc/sections/portfolio/style5.php';
				break;
            
             case 'style6':
				require get_template_directory() . '/inc/sections/portfolio/style6.php';
				break;
                
            case 'style7':
				require get_template_directory() . '/inc/sections/portfolio/style7.php';
				break;
                
            case 'style8':
				require get_template_directory() . '/inc/sections/portfolio/style8.php';
				break;
            
            case 'style9':
				require get_template_directory() . '/inc/sections/portfolio/style9.php';
				break;
            case 'style10':
				require get_template_directory() . '/inc/sections/portfolio/style10.php';
				break;
            case 'style11':
				require get_template_directory() . '/inc/sections/portfolio/style11.php';
				break;
            case 'style12':
				require get_template_directory() . '/inc/sections/portfolio/style12.php';
				break;
                case 'style13':
				require get_template_directory() . '/inc/sections/portfolio/style13.php';
				break;
		}
	}
	protected function content_template() {}
    
	public function render_plain_content() {}
}

Plugin::instance()->widgets_manager->register_widget_type(new Elementor_portfolio());
